==> apigateway-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/DomainNameAttributes.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:27:21.920Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface DomainNameAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The domain name (e.g. `example.com`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDomainName();

    /**
     * Thje Route53 hosted zone ID to use in order to connect a record set to this domain through an alias.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDomainNameAliasHostedZoneId();

    /**
     * The Route53 alias target to use in order to connect a record set to this domain through an alias.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDomainNameAliasTarget();

    /**
     * @return a {@link Builder} of {@link DomainNameAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link DomainNameAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String domainName;
        private java.lang.String domainNameAliasHostedZoneId;
        private java.lang.String domainNameAliasTarget;

        /**
         * Sets the value of DomainName
         * @param domainName The domain name (e.g. `example.com`). This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainName(java.lang.String domainName) {
            this.domainName = domainName;
            return this;
        }

        /**
         * Sets the value of DomainNameAliasHostedZoneId
         * @param domainNameAliasHostedZoneId Thje Route53 hosted zone ID to use in order to connect a record set to this domain through an alias. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainNameAliasHostedZoneId(java.lang.String domainNameAliasHostedZoneId) {
            this.domainNameAliasHostedZoneId = domainNameAliasHostedZoneId;
            return this;
        }

        /**
         * Sets the value of DomainNameAliasTarget
         * @param domainNameAliasTarget The Route53 alias target to use in order to connect a record set to this domain through an alias. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainNameAliasTarget(java.lang.String domainNameAliasTarget) {
            this.domainNameAliasTarget = domainNameAliasTarget;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link DomainNameAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public DomainNameAttributes build() {
            return new Jsii$Proxy(domainName, domainNameAliasHostedZoneId, domainNameAliasTarget);
        }
    }

    /**
     * An implementation for {@link DomainNameAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements DomainNameAttributes {
        private final java.lang.String domainName;
        private final java.lang.String domainNameAliasHostedZoneId;
        private final java.lang.String domainNameAliasTarget;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.domainName = this.jsiiGet("domainName", java.lang.String.class);
            this.domainNameAliasHostedZoneId = this.jsiiGet("domainNameAliasHostedZoneId", java.lang.String.class);
            this.domainNameAliasTarget = this.jsiiGet("domainNameAliasTarget", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String domainName, java.lang.String domainNameAliasHostedZoneId, java.lang.String domainNameAliasTarget) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainName = java.util.Objects.requireNonNull(domainName, "domainName is required");
            this.domainNameAliasHostedZoneId = java.util.Objects.requireNonNull(domainNameAliasHostedZoneId, "domainNameAliasHostedZoneId is required");
            this.domainNameAliasTarget = java.util.Objects.requireNonNull(domainNameAliasTarget, "domainNameAliasTarget is required");
        }

        @Override
        public java.lang.String getDomainName() {
            return this.domainName;
        }

        @Override
        public java.lang.String getDomainNameAliasHostedZoneId() {
            return this.domainNameAliasHostedZoneId;
        }

        @Override
        public java.lang.String getDomainNameAliasTarget() {
            return this.domainNameAliasTarget;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("domainName", om.valueToTree(this.getDomainName()));
            obj.set("domainNameAliasHostedZoneId", om.valueToTree(this.getDomainNameAliasHostedZoneId()));
            obj.set("domainNameAliasTarget", om.valueToTree(this.getDomainNameAliasTarget()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            DomainNameAttributes.Jsii$Proxy that = (DomainNameAttributes.Jsii$Proxy) o;

            if (!domainName.equals(that.domainName)) return false;
            if (!domainNameAliasHostedZoneId.equals(that.domainNameAliasHostedZoneId)) return false;
            return this.domainNameAliasTarget.equals(that.domainNameAliasTarget);
        }

        @Override
        public int hashCode() {
            int result = this.domainName.hashCode();
            result = 31 * result + (this.domainNameAliasHostedZoneId.hashCode());
            result = 31 * result + (this.domainNameAliasTarget.hashCode());
            return result;
        }
    }
}

==> apigateway-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/DomainNameAttributes.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:51.589Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.DomainNameAttributes")
@software.amazon.jsii.Jsii.Proxy(DomainNameAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface DomainNameAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The domain name (e.g. `example.com`).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDomainName();

    /**
     * Thje Route53 hosted zone ID to use in order to connect a record set to this domain through an alias.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDomainNameAliasHostedZoneId();

    /**
     * The Route53 alias target to use in order to connect a record set to this domain through an alias.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDomainNameAliasTarget();

    /**
     * @return a {@link Builder} of {@link DomainNameAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link DomainNameAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String domainName;
        private java.lang.String domainNameAliasHostedZoneId;
        private java.lang.String domainNameAliasTarget;

        /**
         * Sets the value of DomainName
         * @param domainName The domain name (e.g. `example.com`). This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainName(java.lang.String domainName) {
            this.domainName = domainName;
            return this;
        }

        /**
         * Sets the value of DomainNameAliasHostedZoneId
         * @param domainNameAliasHostedZoneId Thje Route53 hosted zone ID to use in order to connect a record set to this domain through an alias. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainNameAliasHostedZoneId(java.lang.String domainNameAliasHostedZoneId) {
            this.domainNameAliasHostedZoneId = domainNameAliasHostedZoneId;
            return this;
        }

        /**
         * Sets the value of DomainNameAliasTarget
         * @param domainNameAliasTarget The Route53 alias target to use in order to connect a record set to this domain through an alias. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainNameAliasTarget(java.lang.String domainNameAliasTarget) {
            this.domainNameAliasTarget = domainNameAliasTarget;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link DomainNameAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public DomainNameAttributes build() {
            return new Jsii$Proxy(domainName, domainNameAliasHostedZoneId, domainNameAliasTarget);
        }
    }

    /**
     * An implementation for {@link DomainNameAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements DomainNameAttributes {
        private final java.lang.String domainName;
        private final java.lang.String domainNameAliasHostedZoneId;
        private final java.lang.String domainNameAliasTarget;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domainName = this.jsiiGet("domainName", java.lang.String.class);
            this.domainNameAliasHostedZoneId = this.jsiiGet("domainNameAliasHostedZoneId", java.lang.String.class);
            this.domainNameAliasTarget = this.jsiiGet("domainNameAliasTarget", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String domainName, final java.lang.String domainNameAliasHostedZoneId, final java.lang.String domainNameAliasTarget) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainName = java.util.Objects.requireNonNull(domainName, "domainName is required");
            this.domainNameAliasHostedZoneId = java.util.Objects.requireNonNull(domainNameAliasHostedZoneId, "domainNameAliasHostedZoneId is required");
            this.domainNameAliasTarget = java.util.Objects.requireNonNull(domainNameAliasTarget, "domainNameAliasTarget is required");
        }

        @Override
        public java.lang.String getDomainName() {
            return this.domainName;
        }

        @Override
        public java.lang.String getDomainNameAliasHostedZoneId() {
            return this.domainNameAliasHostedZoneId;
        }

        @Override
        public java.lang.String getDomainNameAliasTarget() {
            return this.domainNameAliasTarget;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("domainName", om.valueToTree(this.getDomainName()));
            data.set("domainNameAliasHostedZoneId", om.valueToTree(this.getDomainNameAliasHostedZoneId()));
            data.set("domainNameAliasTarget", om.valueToTree(this.getDomainNameAliasTarget()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.DomainNameAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            DomainNameAttributes.Jsii$Proxy that = (DomainNameAttributes.Jsii$Proxy) o;

            if (!domainName.equals(that.domainName)) return false;
            if (!domainNameAliasHostedZoneId.equals(that.domainNameAliasHostedZoneId)) return false;
            return this.domainNameAliasTarget.equals(that.domainNameAliasTarget);
        }

        @Override
        public int hashCode() {
            int result = this.domainName.hashCode();
            result = 31 * result + (this.domainNameAliasHostedZoneId.hashCode());
            result = 31 * result + (this.domainNameAliasTarget.hashCode());
            return result;
        }
    }
}
